package com.tecnavia.dailymotion.sdk

import com.facebook.react.bridge.ReactContext
import com.facebook.react.bridge.ReadableArray
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.common.MapBuilder
import com.facebook.react.uimanager.SimpleViewManager
import com.facebook.react.uimanager.ThemedReactContext
import com.facebook.react.uimanager.annotations.ReactProp
import com.facebook.react.uimanager.events.RCTEventEmitter
import com.tecnavia.dailymotion.sdk.listeners.PlayerEventListener
import java.lang.Exception

class TaDailymotionSdkView(private val context: ReactContext) : SimpleViewManager<TaPlayer>() {
    private val mEventEmitter: RCTEventEmitter = context.getJSModule(RCTEventEmitter::class.java)
    companion object {
        const val REACT_CLASS = "RCTDailyMotionPlayer"
        const val COMMAND_PLAY = 0
        const val COMMAND_PAUSE = 1
        const val COMMAND_SEEK = 2
        const val COMMAND_MUTE = 3
        const val COMMAND_UNMUTE = 4
        const val COMMAND_RELEASE = 5
        const val COMMAND_FULLSCREEN_BUTTON = 6
    }

    override fun getName(): String {
        return REACT_CLASS
    }

    override fun createViewInstance(themedReactContext: ThemedReactContext): TaPlayer {
        return TaPlayer(themedReactContext, mEventEmitter)
    }

    @ReactProp(name = "playerData")
    fun setPlayerData(view: TaPlayer, map: ReadableMap?) {
        view.setPlayerData(map!!.toHashMap())
    }

    override fun onAfterUpdateTransaction(view: TaPlayer) {
        super.onAfterUpdateTransaction(view)
        view.load()
    }

    override fun receiveCommand(root: TaPlayer, commandId: String, args: ReadableArray?) {
        super.receiveCommand(root, commandId, args)
        try {
            when (commandId.toInt()) {
                COMMAND_PAUSE -> root.getPlayer()?.pause()
                COMMAND_PLAY -> root.play()
                COMMAND_SEEK -> root.getPlayer()?.seekTo(args!!.getInt(0).toLong())
                COMMAND_MUTE -> root.getPlayer()?.setMute(true)
                COMMAND_UNMUTE -> root.getPlayer()?.setMute(false)
                COMMAND_RELEASE -> root.getPlayer()?.destroy()
                COMMAND_FULLSCREEN_BUTTON -> root.toggleFullscreen()
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    /** Map the "create" command to an integer */
    override fun getCommandsMap(): Map<String, Int>? {
        val builder = MapBuilder.builder<String, Int>()
        builder.put("play", COMMAND_PLAY)
        builder.put("pause", COMMAND_PAUSE)
        builder.put("mute", COMMAND_MUTE)
        builder.put("unmute", COMMAND_UNMUTE)
        builder.put("seek", COMMAND_SEEK)
        builder.put("release", COMMAND_RELEASE)
        builder.put("fullscreenButton", COMMAND_FULLSCREEN_BUTTON)
        return builder.build()
    }

    override fun getExportedCustomDirectEventTypeConstants(): Map<String, Any>? {

        val builder = MapBuilder.builder<String, Any>()
        builder.put(
                PlayerEventListener.ON_PLAYER_EVENT,
                MapBuilder.of("registrationName", PlayerEventListener.ON_PLAYER_EVENT)
        )
        builder.put(
                PlayerEventListener.ON_PLAYER_ERROR,
                MapBuilder.of("registrationName", PlayerEventListener.ON_PLAYER_ERROR)
        )
        return builder.build()
    }
}
