package com.tecnavia.dailymotion.sdk.listeners

import android.view.View
import com.dailymotion.player.android.sdk.PlayerView
import com.dailymotion.player.android.sdk.listeners.PlayerListener
import com.dailymotion.player.android.sdk.listeners.VideoListener
import com.dailymotion.player.android.sdk.webview.error.PlayerError
import com.facebook.react.bridge.Arguments
import com.facebook.react.bridge.WritableMap
import com.facebook.react.uimanager.events.RCTEventEmitter

open class PlayerEventListener(
        mEventEmitter: RCTEventEmitter?,
        rootView: View,
        handler: EventHandler
) : TAPlayerListener(mEventEmitter!!, rootView, handler), PlayerListener, VideoListener {
    override fun onPlayerError(playerView: PlayerView, error: PlayerError) {
        val map = Arguments.createMap()
        map.putString("name", "error")
        map.putString("description", error.message)
        send(ON_PLAYER_ERROR, map)
    }

    fun onPlayerLoaded(playerView: PlayerView) {
        sendEvent(playerView, "loaded")
    }

    override fun onPlayerStart(playerView: PlayerView) {
        sendEvent(playerView, "start")
    }

    override fun onPlayerEnd(playerView: PlayerView) {
        // player end event
        sendEvent(playerView,"end")
    }

    override fun onVideoStart(playerView: PlayerView) {
        sendEvent(playerView,"video_start")
    }

    override fun onVideoEnd(playerView: PlayerView) {
        sendEvent(playerView,"video_end")
    }

    override fun onVideoPlay(playerView: PlayerView) {
        sendEvent(playerView,"play")
    }

    override fun onVideoPlaying(playerView: PlayerView) {
        sendEvent(playerView,"playing")
    }

    override fun onVideoBuffering(playerView: PlayerView) {
        sendEvent(playerView, "waiting")
    }

    override fun onVideoPause(playerView: PlayerView) {
        sendEvent(playerView, "pause")
    }

    override fun onVideoSeekStart(playerView: PlayerView, time: Long) {
        val data = Arguments.createMap()
        data.putDouble("time", time.toDouble())
        sendEvent(playerView, "seeking", data)
    }

    override fun onVideoSeekEnd(playerView: PlayerView, time: Long) {
        val data = Arguments.createMap()
        data.putDouble("time", time.toDouble())
        sendEvent(playerView, "seeked", data)
    }

    private fun sendEvent(playerView: PlayerView, name: String?, data: WritableMap? = null) {
        val map = Arguments.createMap()
        map.putString("name", name)
        if (data == null) {
            map.putMap("data", Arguments.createMap())
        } else {
            map.putMap("data", data)
        }
        send(ON_PLAYER_EVENT, map)
    }

    companion object {
        const val ON_PLAYER_EVENT = "onPlayerEvent"
        const val ON_PLAYER_ERROR = "onPlayerError"
    }
}
