//
//  RNDailyMotionSdkView.swift
//  react-native-dailymotion-sdk
//
//  Created by iPad Developer on 03.03.23.
//

import Foundation
import DailymotionPlayerSDK

class RCTDailyMotionPlayerController: UIViewController {

    private var playerView: DMPlayerView?;
    private var onPlayerEvent: RCTDirectEventBlock?;
    private var onPlayerError: RCTDirectEventBlock?;
    
    init(playerData: NSDictionary) {
        
        self.playerView = nil
        super.init(nibName: nil, bundle: nil)
        
        let playerId = playerData.object(forKey: "playerId") ?? "0"
        let videoId =  playerData.object(forKey: "video") ?? "0"
        
        var dmPlayerParameters = DMPlayerParameters()
        dmPlayerParameters.allowIDFA = playerData.object(forKey: "allowIDFA") as? Bool ?? false
        dmPlayerParameters.allowPIP = playerData.object(forKey: "allowPIP") as? Bool ?? false
        dmPlayerParameters.mute = playerData.object(forKey: "mute") as? Bool ?? false
        dmPlayerParameters.startTime = playerData.object(forKey: "startTime") as? TimeInterval
        dmPlayerParameters.loop = playerData.object(forKey: "loop") as? Bool ?? false
        
        // Please replace the Player ID with your own Player ID accessed via the Dailymotion Studio or Platform API
        Dailymotion.createPlayer(playerId: playerId as! String, videoId: videoId as? String, playerParameters: dmPlayerParameters, playerDelegate: self, videoDelegate: self, adDelegate: self) {
            [weak self] playerView, error in
              // Wait for Player initialisation and check if self is still allocated
              guard let self = self else {
                return
              }
              // Check For errors
              if let error = error {
                print("Error creating player: \(error)")
              } else {
                  guard let playerView = playerView else {
                      return
                  }
                  
                  self.playerView = playerView;
                  
                  if (self.playerView == nil) {
                      return
                  }
                  
                  self.view.addSubview(self.playerView!)
                  self.view.bringSubviewToFront(self.playerView!)
                  
                  // Attach the created Player View to your player container View
                  let constraints = [
                    self.playerView!.topAnchor.constraint(equalTo: self.view.topAnchor, constant: 0),
                    self.playerView!.bottomAnchor.constraint(equalTo: self.view.bottomAnchor, constant: 0),
                    self.playerView!.leadingAnchor.constraint(equalTo: self.view.leadingAnchor, constant: 0),
                    self.playerView!.trailingAnchor.constraint(equalTo: self.view.trailingAnchor, constant: 0)
                  ]
                  // Activate created constraints
                  NSLayoutConstraint.activate(constraints)

                  self.onPlayerEvent?(["name": "loaded", "data": [:]])
              }
        }
            
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func setFrame(_ frame: CGRect) {
        self.view.frame = frame
        self.playerView?.frame = frame
    }
    
    func setPlayerEventCallback(_ callback: RCTDirectEventBlock?) {
        self.onPlayerEvent = callback
    }
    
    func setPlayerErrorCallback(_ callback: RCTDirectEventBlock?) {
        self.onPlayerError = callback
    }
    
    func play() {
        self.playerView?.play()
    }
    
    func play(_ payload: NSDictionary) {
        //if no video id provided pass a default cvalue
        let videoId = payload.object(forKey: "video") ?? "0"
        let playlistId = payload.object(forKey: "playlist")
        let startTime = payload.object(forKey: "startTime")
        self.playerView?.loadContent(videoId: videoId as? String, playlistId: playlistId as? String, startTime: startTime as? TimeInterval)
    }
    
    func pause() {
        self.playerView?.pause()
    }
    
    func seek(_ seconds: NSNumber) {
        self.playerView?.seek(to: TimeInterval(seconds.doubleValue))
    }
    
    func mute() {
        self.playerView?.setMute(mute: true)
    }
    
    func unmute() {
        self.playerView?.setMute(mute: false)
    }
}

extension RCTDailyMotionPlayerController: DMPlayerDelegate, DMAdDelegate, DMVideoDelegate {
    func player(_ player: DMPlayerView, openUrl url: URL) {
    }
    
    func playerWillPresentFullscreenViewController(_ player: DMPlayerView) -> UIViewController? {
      return self
    }
    
    func playerWillPresentAdInParentViewController(_ player: DMPlayerView) -> UIViewController {
      return self
    }
    
    func player(_ player: DMPlayerView, didFailWithError error: Error) {
        self.onPlayerError?(["name": "error", "description": error.localizedDescription])
    }
    
    func playerDidStart(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "start", "data": [:]])
    }
    
    func playerDidEnd(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "end", "data": [:]])
    }
    
    func videoIsPlaying(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "playing", "data": [:]])
    }
    
    func videoDidPlay(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "play", "data": [:]])
    }
    
    func videoIsBuffering(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "waiting", "data": [:]])
    }
    
    func videoDidPause(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "pause", "data": [:]])
    }
    
    func video(_ player: DMPlayerView, didSeekStart time: Double) {
        self.onPlayerEvent?(["name": "seeking", "data": ["time": time]])
    }
    
    func video(_ player: DMPlayerView, didSeekEnd time: Double) {
        self.onPlayerEvent?(["name": "seeked", "data": ["time": time]])
    }
    
    func videoDidStart(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "video_start", "data": [:]])
    }
    
    func videoDidEnd(_ player: DMPlayerView) {
        self.onPlayerEvent?(["name": "video_end", "data": [:]])
    }
}
