//
//  RNDailymotionSdkViewManager.m
//  react-native-dailymotion-sdk
//
//  Created by iPad Developer on 06.03.23.
//
#import <React/RCTUIManager.h>
#import <React/RCTLog.h>
#import "RCTDailyMotionPlayerManager.h"

#if __has_include(<react_native_dailymotion_sdk/react_native_dailymotion_sdk-Swift.h>)
#import <react_native_dailymotion_sdk/react_native_dailymotion_sdk-Swift.h>
#else
#import "react_native_dailymotion_sdk-Swift.h"
#endif

@implementation RCTDailyMotionPlayerManager

RCT_EXPORT_MODULE();

- (UIView *)view
{
  return [[RCTDailyMotionPlayer alloc] init];
}

// exported view property to be set in React Native
RCT_EXPORT_VIEW_PROPERTY(playerData, NSDictionary);
RCT_EXPORT_VIEW_PROPERTY(onPlayerEvent, RCTDirectEventBlock);
RCT_EXPORT_VIEW_PROPERTY(onPlayerError, RCTDirectEventBlock);

RCT_EXPORT_METHOD(play:(nonnull NSNumber*) reactTag) {
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *,UIView *> *viewRegistry) {
        RCTDailyMotionPlayer *view = viewRegistry[reactTag];
        if (!view || ![view isKindOfClass:[RCTDailyMotionPlayer class]]) {
            RCTLogError(@"Cannot find RCTDailyMotionPlayer with tag #%@", reactTag);
            return;
        }
        [view play];
    }];
}

RCT_EXPORT_METHOD(pause:(nonnull NSNumber*) reactTag) {
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *,UIView *> *viewRegistry) {
        RCTDailyMotionPlayer *view = viewRegistry[reactTag];
        if (!view || ![view isKindOfClass:[RCTDailyMotionPlayer class]]) {
            RCTLogError(@"Cannot find RCTDailyMotionPlayer with tag #%@", reactTag);
            return;
        }
        [view pause];
    }];
}

RCT_EXPORT_METHOD(seek:(nonnull NSNumber*) reactTag seconds:(nonnull NSNumber*) seconds) {
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *,UIView *> *viewRegistry) {
        RCTDailyMotionPlayer *view = viewRegistry[reactTag];
        if (!view || ![view isKindOfClass:[RCTDailyMotionPlayer class]]) {
            RCTLogError(@"Cannot find RCTDailyMotionPlayer with tag #%@", reactTag);
            return;
        }
        [view seek:seconds];
    }];
}

RCT_EXPORT_METHOD(mute:(nonnull NSNumber*) reactTag) {
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *,UIView *> *viewRegistry) {
        RCTDailyMotionPlayer *view = viewRegistry[reactTag];
        if (!view || ![view isKindOfClass:[RCTDailyMotionPlayer class]]) {
            RCTLogError(@"Cannot find RCTDailyMotionPlayer with tag #%@", reactTag);
            return;
        }
        [view mute];
    }];
}

RCT_EXPORT_METHOD(unmute:(nonnull NSNumber*) reactTag) {
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *,UIView *> *viewRegistry) {
        RCTDailyMotionPlayer *view = viewRegistry[reactTag];
        if (!view || ![view isKindOfClass:[RCTDailyMotionPlayer class]]) {
            RCTLogError(@"Cannot find RCTDailyMotionPlayer with tag #%@", reactTag);
            return;
        }
        [view unmute];
    }];
}

RCT_EXPORT_METHOD(release:(nonnull NSNumber*) reactTag) {
    RCTLogWarn(@"RCTDailyMotionPlayer method 'release' not implemented");
}

@end
